using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;
using System.Collections.Generic;
using MonoTouch.ObjCRuntime;

namespace StackedBarExample
{

	public class DataModel : NSObject
	{
		[Export("Label")]
		public string Label { get; set; }
		[Export("Value1")]
		public float Value1 { get; set; }
		[Export("Value2")]
		public float Value2 { get; set; }
		[Export("Value3")]
		public float Value3 { get; set; }
	}

	public class MyChartViewDelegate :IGChartViewDelegate
	{
	
		public override string ResolveLabelForAxis (IGChartView chartView, IGAxis axis, NSObject item)
		{
			// NOTE: Don't call the base implementation on a Model class
			// see http://docs.xamarin.com/ios/tutorials/Events%2c_Protocols_and_Delegates 



			// so at this point you would need to change the labels for the axis labels to custom labels
			// so filter out to only do X axis labels (in this case)
			if (axis is IGNumericXAxis) {
				return "hello World";
			}

			// since this chart only has 2 axis, we know that the y axis is being processed but adding this extra logic 
			// check for completeneess
			if (axis is IGCategoryYAxis)
			{
				// For this case we need to get the value off our data object
				NSMutableDictionary dm = (NSMutableDictionary)item;
				return ((NSString)dm["label"]).ToString();
			}

			// if we get here, well we make an error label
			return "SomethingWentWrong";
		}

	}


	public partial class StackedBarExampleViewController : UIViewController
	{

		IGChartView _chartView;
		IGStackedSeriesDataSourceHelper _stackedChartDataSourceHelper;
		IGLegend _legend;
		List<NSObject> _data;

		static bool UserInterfaceIdiomIsPhone {
			get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
		}

		public StackedBarExampleViewController ()
			: base (UserInterfaceIdiomIsPhone ? "StackedBarExampleViewController_iPhone" : "StackedBarExampleViewController_iPad", null)
		{
		}

		public override void DidReceiveMemoryWarning ()
		{
			// Releases the view if it doesn't have a superview.
			base.DidReceiveMemoryWarning ();
			
			// Release any cached data, images, etc that aren't in use.
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();
			
			// Perform any additional setup after loading the view, typically from a nib.


			this.PopulateData();
			RectangleF bounds = new RectangleF(0, 0, this.View.Frame.Size.Width, this.View.Frame.Size.Height);
			_chartView = new IGChartView(bounds);
			_chartView.BackgroundColor = UIColor.White;



			_chartView.Delegate = new MyChartViewDelegate();



			List<NSString> valueList = new List<NSString> ();
			valueList.Add (new NSString("Value1"));
			valueList.Add (new NSString("Value2"));
			valueList.Add (new NSString("Value3"));

			_stackedChartDataSourceHelper = new IGStackedSeriesDataSourceHelper(  _data.ToArray(), 
			                                                                   
			                                                            
			                                                                    valueList.ToArray());


			// the labels are usually pulled off hte datasource, 
			// so they would be fed into the view by the dataSourceHelper object.  This is what you normally 
			// would do, but since we want to do a custom label we will be implmenting the chart delegate and 
			// have to make our labels ourselves.
			_stackedChartDataSourceHelper.LabelPath = "Label";




			_chartView.AddStackedSeries(new Class(typeof(IGStackedBarSeries)), "series", _stackedChartDataSourceHelper, "xAxis", "yAxis");
			(this.View).AddSubview(_chartView);
			_legend = new IGLegend(IGChartLegendType.IGChartLegendTypeSeries);
			_legend.Frame = new RectangleF(20, 20, 100, 100);
			_chartView.Legend = _legend;
			(this.View).AddSubview(_legend);

			// sets the X-Axis labels to be red 
			IGStackedBarSeries s = (IGStackedBarSeries)_chartView.Series [0];
			s.XAxis.LabelBrush = new IGBrush (UIColor.Red);


		}

		public override bool ShouldAutorotateToInterfaceOrientation (UIInterfaceOrientation toInterfaceOrientation)
		{
			// Return true for supported orientations
			if (UserInterfaceIdiomIsPhone) {
				return (toInterfaceOrientation != UIInterfaceOrientation.PortraitUpsideDown);
			} else {
				return true;
			}
		}


		void PopulateData()
		{
			_data = new List<NSObject>();
			for (int i = 0; i < 10; i++) {
				DataModel item = new DataModel();
				item.Value1 = new Random((int)DateTime.Now.Ticks).Next(100);
				item.Value2 = new Random((int)DateTime.Now.Ticks).Next(100);
				item.Value3 = new Random((int)DateTime.Now.Ticks).Next(100);
				item.Label = string.Format ("MYDATA {0}", i);
				_data.Add(item);
			}      
		}
	}
}

